SystemOrganization addCategory: #FuelPackageLoader!
SystemOrganization addCategory: #'FuelPackageLoader-Mappers'!
SystemOrganization addCategory: #'FuelPackageLoader-Metacello'!

FLFullGeneralMapper subclass: #FLPackageLoaderGeneralMapper
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoader-Mappers'!

!FLPackageLoaderGeneralMapper commentStamp: 'MartinDias 8/24/2011 00:08' prior: 0!
I am like the default mapper but with a special behavior with classes. I store a copy each class with just the local protocol.!

!FLPackageLoaderGeneralMapper methodsFor: 'visiting' stamp: 'MarianoMartinezPeck 5/15/2012 12:00'!
visitClass: aClass  

	((self clusterKeyedByClusterName: FLSubstitutionCluster) isSubstitute: aClass )
		ifTrue:  [ super visitClass: aClass ]
		ifFalse: [ self visitSubstitution: aClass by: aClass copyWithLocalProtocol ]
		
" The other possibility is to do the following, but this is slower
	(Smalltalk globals identityIncludes: aClass)
		ifTrue: [ self visitSubstitution: aClass by: aClass copyWithLocalProtocol ]
		ifFalse: [ super visitClass: aClass ]"! !

!FLPackageLoaderGeneralMapper methodsFor: 'visiting' stamp: 'MarianoMartinezPeck 5/15/2012 12:00'!
visitMetaclass: aMetaclass

	"We should find a better way of doing this"
	self flag: #fixIt.
	
	((self clusterKeyedByClusterName: FLSubstitutionCluster) isSubstitute:  aMetaclass theNonMetaClass)
		ifTrue: [ super visitMetaclass: aMetaclass ]
		ifFalse:  [ self visitSubstitution: aMetaclass by: ((self clusterKeyedByClusterName: FLSubstitutionCluster) substitutions at: aMetaclass theNonMetaClass ) class].		
	
	"  The other possibility is to do the following, but this is slower
	(Smalltalk globals identityIncludes: aMetaclass theNonMetaClass)
		ifTrue: [ self visitSubstitution: aMetaclass by: ((self clusterKeyedByClusterName: FLClassCluster) objects detect: [:each | each name =  aMetaclass theNonMetaClass name]) class ]
		ifFalse: [ super visitMetaclass: aMetaclass ]"! !

!ClassOrganizer methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 4/29/2012 20:41'!
classifySilently: element under: heading suppressIfDefault: aBoolean

	SystemChangeNotifier uniqueInstance doSilently: [
		super classify: element under: heading suppressIfDefault: aBoolean
	].
! !

!ClassOrganizer methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 8/22/2011 01:32'!
removeCategorySilently: cat 

	super removeCategory: cat! !

!Association methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 5/13/2012 15:22'!
rebindOn: aCompiledMethod at: index
	"If the CompiledMethod was saved with a reference to a class that does exist, then its calculated binding will be nil. In that case we prefer to keep the original association."
	key isNil ifTrue: [^ self].
	(aCompiledMethod methodClass bindingOf: key)
		ifNotNil: [:aBinding |
			aCompiledMethod literalAt: index put: aBinding]! !

!Behavior methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 9/22/2011 15:35'!
rebindMethodDictionary

	self methodDict valuesDo: [ :aCompiledMethod | 
		aCompiledMethod 
			methodClass: self;
			rebindLiterals. ]! !

!TClassAndTraitDescription methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 8/22/2011 00:27'!
removeCategorySilently: aCategory

	SystemChangeNotifier uniqueInstance doSilently: [ self removeCategory: aCategory ]! !

FLAnalyzer subclass: #FLPackageAnalyzer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoader'!

!FLPackageAnalyzer methodsFor: 'defaults' stamp: 'MarianoMartinezPeck 12/14/2011 20:44'!
generalMapper

	^FLPackageLoaderGeneralMapper new! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 8/22/2011 21:16'!
cleanUpClassVariables

	self classPool keys do: [ :key | classPool at: key put: nil ]! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 8/22/2011 21:41'!
cleanUpInstanceVariables

	Class instSize + 1 to: self class instSize do:
		[:offset | self instVarAt: offset put: nil].
! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 5/13/2012 15:14'!
copyMethods
	self methodDict copyMethods.
	self class methodDict copyMethods.
! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 5/15/2012 10:44'!
copyWithLocalProtocol

	| copy |
	copy := self copy.
	"When we copy the methodDict, the methods are not copies. Since we modify them (like in #rebindClassVariablesInMethods) we cannot modify the original methods. Hence, we have to copy also the methods"
	copy copyMethods.
	copy organization: organization deepCopy.
	copy class organization: self classSide organization deepCopy.
	"Class comments are stored in RemoteString that will be broken in different images. By default they are nilled out."
	copy organization classComment: nil.
	copy class organization classComment: nil.
	copy environment: environment.
	copy basicCategory: category.	
	copy traitComposition: self traitComposition.
	copy classSide traitComposition: self classSide traitComposition.
	copy removeForeignProtocol.
	copy classSide removeForeignProtocol.
	copy cleanUpClassVariables.
	copy cleanUpInstanceVariables.
	"Class variables were set to nil. There can be class methods that hold wrong values and have to be updated to the new classPool."
	copy rebindClassVariablesInMethods.
	^copy! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 9/29/2011 01:30'!
initializeOnLoad

	(self class includesSelector: #initialize)
		ifTrue: [self initialize]! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 5/13/2012 15:20'!
rebindClassVariablesInMethods

	self class methodDict valuesDo: [ :aCompiledMethod | 
		1 to: aCompiledMethod numLiterals-1 do: [ :index | 
			| literal |
			literal := aCompiledMethod literalAt: index.
			literal isVariableBinding ifTrue: [
				(self innerBindingOf: literal key) ifNotNil: [:aBinding |
					aCompiledMethod literalAt: index put: aBinding
				]
			]
		]
	]! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 9/29/2011 01:29'!
rebindOnLoad

	self rebindMethodDictionary.
	self class rebindMethodDictionary! !

!Class methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 9/29/2011 01:29'!
registerOnLoad

	superclass addSubclass: self. "Note that aClass could already be between its superclass subclasses, #addSubclass: is prepared for that case."
	Smalltalk globals at: self name put: self.
	Smalltalk globals organization classify: self name under: self basicCategory.! !

!CompiledMethod methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 9/22/2011 02:10'!
rebindLiteralAt: index

	(self literalAt: index) rebindOn: self at: index! !

!CompiledMethod methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 5/13/2012 15:15'!
rebindLiterals 

	1 to: self numLiterals
		do: [ :index | self rebindLiteralAt: index ]! !

!MethodDictionary methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 5/13/2012 15:14'!
copyMethods
	self keysAndValuesDo: [:selector :method |
		self at: selector put: method copy.
		]! !

!Trait methodsFor: '*FuelPackageLoader' stamp: 'PavelKrivanek 4/11/2012 17:21'!
rebindMethodDictionary

	self methodDict valuesDo: [ :aCompiledMethod | 
		aCompiledMethod 
			methodClass: self;
			rebindLiterals. ]! !

!Trait methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 4/16/2012 20:27'!
rebindOnLoad

	self rebindMethodDictionary.
	self class rebindMethodDictionary
	! !

!Trait methodsFor: '*FuelPackageLoader' stamp: 'PavelKrivanek 4/11/2012 17:19'!
registerOnLoad

	Smalltalk globals at: self name put: self.
	Smalltalk globals organization classify: self name under: self basicCategory.! !

Object subclass: #FLMethodExtension
	instanceVariableNames: 'method category'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoader'!

!FLMethodExtension class methodsFor: 'instance creation' stamp: 'MartinDias 9/29/2011 01:53'!
with: aCompiledMethod

	^ self basicNew
		initializeWith: aCompiledMethod;
		yourself ! !

!FLMethodExtension methodsFor: 'accessing' stamp: 'MartinDias 3/26/2011 04:40'!
category
	^ category! !

!FLMethodExtension methodsFor: 'initialize-release' stamp: 'MartinDias 9/29/2011 01:52'!
initializeWith: aCompiledMethod

	self initialize.
	method := aCompiledMethod.
	category := aCompiledMethod category.! !

!FLMethodExtension methodsFor: 'loading' stamp: 'asdas 4/18/2012 19:10'!
load
	method rebindLiterals.
	method methodClass addSelectorSilently: method selector withMethod: method.
	method methodClass organization classifySilently: method selector under: category suppressIfDefault: true.

! !

!FLMethodExtension methodsFor: 'accessing' stamp: 'MartinDias 3/26/2011 04:40'!
method
	^ method! !

Object subclass: #FLPackage
	instanceVariableNames: 'extensionMethods behaviors mustInitialize preLoadActions postLoadActions additionalObjects packageHeader'
	classVariableNames: 'MustInitializeByDefault'
	poolDictionaries: ''
	category: 'FuelPackageLoader'!

!FLPackage class methodsFor: 'private' stamp: 'MarianoMartinezPeck 4/16/2012 20:19'!
behaviorsLocalTo: packageInfo
	"Unfortuntly, the message #classes is a bad name because it answers both, classes and traits"
	^ packageInfo classes! !

!FLPackage class methodsFor: 'private' stamp: 'MartinDias 8/21/2011 19:21'!
extensionMethodsTo: packageInfo
	^ packageInfo extensionMethods 
		collect: [ :reference | FLMethodExtension with: reference compiledMethod ]! !

!FLPackage class methodsFor: 'initializers' stamp: 'MarianoMartinezPeck 5/15/2012 18:17'!
mustInitializeByDefault

	^ MustInitializeByDefault ifNil: [ MustInitializeByDefault := true ].! !

!FLPackage class methodsFor: 'initializers' stamp: 'MarianoMartinezPeck 5/15/2012 18:17'!
mustInitializeByDefault: aBoolean

	MustInitializeByDefault := aBoolean! !

!FLPackage class methodsFor: 'instance creation' stamp: 'MarianoMartinezPeck 4/16/2012 20:21'!
named: packageName

	| packageInfo |
	packageInfo := PackageInfo named: packageName.
	^ self basicNew
		initializeWithBehaviors: (self behaviorsLocalTo: packageInfo) 
		extensionMethods: (self extensionMethodsTo: packageInfo);
		yourself! !

!FLPackage class methodsFor: 'instance creation' stamp: 'MarianoMartinezPeck 4/16/2012 20:21'!
withPackages: packageNames

	| behaviors methods packageInfo |
	behaviors := OrderedCollection new.
	methods := OrderedCollection new.
	packageNames do: [:packageName |
		packageInfo := PackageInfo named: packageName.
		behaviors addAll: (self behaviorsLocalTo: packageInfo).
		methods addAll: (self extensionMethodsTo: packageInfo)].
	
	^ self basicNew
		initializeWithBehaviors: behaviors
		extensionMethods: methods;
		yourself! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/15/2012 23:41'!
addPostLoadAction: aCleanBlockClosure
	"The closure can (or not) to have one parameter and it will be the package."
	aCleanBlockClosure isClean ifFalse: [ self error: 'Post load actions have to be clean closures. For more details see method BlocKClosure >> #isClean' ].
	postLoadActions add: aCleanBlockClosure ! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/16/2012 19:39'!
addPreLoadAction: aCleanBlockClosure
	"The closure can (or not) to have one parameter and it will be the package."
	aCleanBlockClosure isClean ifFalse: [ self error: 'Pre load actions have to be clean closures. For more details see method BlocKClosure >> #isClean' ].
	preLoadActions add: aCleanBlockClosure ! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/15/2012 22:42'!
additionalObjectAt: aKey
	^ additionalObjects at: aKey! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/15/2012 22:34'!
at: key putAdditionalObject: anObject 
	"This is useful if we want to attach objects to a package that will also be serialized. The way they are stored is key-value."
	additionalObjects at: key put: anObject! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 4/16/2012 20:17'!
behaviors
	^ behaviors! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 4/17/2012 17:38'!
classes
	^ behaviors select: [:each | each isBehavior]! !

!FLPackage methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/15/2012 23:13'!
executePostLoadActions
	postLoadActions do: [:each | each cull: self]! !

!FLPackage methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/15/2012 23:15'!
executePreLoadActions
	preLoadActions do: [:each | each cull: self]! !

!FLPackage methodsFor: 'accessing' stamp: 'MartinDias 3/26/2011 03:35'!
extensionMethods
	^ extensionMethods! !

!FLPackage methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/20/2012 15:17'!
initializeClasses
	"We should not send #initialize to traits"
	(self classes sort: [:a :b | a allSuperclasses size < b allSuperclasses size ])
 		do: [:aClass | aClass initializeOnLoad].! !

!FLPackage methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/20/2012 15:17'!
initializeClassesIfNecessary
	self mustInitialize ifTrue: [self initializeClasses]! !

!FLPackage methodsFor: 'initialize-release' stamp: 'MarianoMartinezPeck 5/16/2012 19:43'!
initializeWithBehaviors: someBehaviors extensionMethods: someExtensionMethods

	self initialize.
	behaviors := someBehaviors.
	extensionMethods := someExtensionMethods.
	mustInitialize := self class mustInitializeByDefault.
	preLoadActions := OrderedCollection new.
	postLoadActions := OrderedCollection new.
	additionalObjects := IdentityDictionary new.
	packageHeader := FLPackageHeader new.! !

!FLPackage methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/20/2012 15:09'!
load
	self executePreLoadActions.
	self behaviors do: [:aBehavior | aBehavior registerOnLoad].
	Smalltalk globals flushClassNameCache.
	self behaviors do: [:aBehavior | aBehavior rebindOnLoad].
	self behaviors do: [:aBehavior | self notifyBehaviorAddition: aBehavior].
	self loadExtensionMethods.
	Behavior flushObsoleteSubclasses.
	self initializeClassesIfNecessary.
	self executePostLoadActions.! !

!FLPackage methodsFor: 'loading' stamp: 'MartinDias 3/26/2011 04:44'!
loadExtensionMethods
	
	extensionMethods do: [ :extensionMethod | extensionMethod load ]! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/15/2012 18:44'!
mustInitialize
	
	^ mustInitialize! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/15/2012 18:44'!
mustInitialize: aBoolean
	
	mustInitialize := aBoolean! !

!FLPackage methodsFor: 'loading' stamp: 'MarianoMartinezPeck 4/19/2012 23:06'!
notifyBehaviorAddition: aBehavior

	 | category |

	category := aBehavior category ifNil: ['UNKNOWN'].
	"It looks like Traits use the same even than classes"
	SystemChangeNotifier uniqueInstance classAdded: aBehavior inCategory: category asSymbol.

! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/11/2012 11:44'!
originalExtensionMethods
	^ extensionMethods collect: [:each | each method]! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/16/2012 19:46'!
packageHeader
	
	^ packageHeader! !

!FLPackage methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/16/2012 19:46'!
packageHeader: anObject
	
	packageHeader := anObject! !

Object subclass: #FLPackageHeader
	instanceVariableNames: 'preMaterializationActions additionalObjects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoader'!

!FLPackageHeader methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/16/2012 19:38'!
addPreMaterializationAction: aCleanBlockClosure
	"The closure can (or not) to have one parameter and it will be the package."
	aCleanBlockClosure isClean ifFalse: [ self error: 'Pre materializaton actions have to be clean closures. For more details see method BlocKClosure >> #isClean' ].
	preMaterializationActions add: aCleanBlockClosure ! !

!FLPackageHeader methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/16/2012 19:40'!
at: key putAdditionalObject: anObject 
	"This is useful if we want to attach objects to a package that will also be serialized. The way they are stored is key-value."
	additionalObjects at: key put: anObject! !

!FLPackageHeader methodsFor: 'executing' stamp: 'MarianoMartinezPeck 5/16/2012 19:47'!
executePreMaterializationActions
	preMaterializationActions do: [:each | each cull: self]! !

!FLPackageHeader methodsFor: 'initialize-release' stamp: 'MarianoMartinezPeck 5/16/2012 19:41'!
initialize
	additionalObjects := IdentityDictionary new.
	preMaterializationActions := OrderedCollection new.! !

Object subclass: #FLPackageLoader
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoader'!

!FLPackageLoader methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/22/2012 15:00'!
loadFrom: aStream
	| package |
	package := self materializeFrom: aStream.
	package load.
	^ package! !

!FLPackageLoader methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/20/2012 15:16'!
loadSortedPackagesFromDifferentStreamsInDirectory: aDirectory 
	"This method should only be used if you have stored with the method #storeInDifferentStreamsSortedPackageNames: packageNames onDirectory: aDirecotory. This method does the initialization of classes in the order the packages were originally provided.  "
	| packageNames packages |
	
	packages := OrderedCollection new.
	
	aDirectory readOnlyFileNamed: 'listOfPackagesInOrder.fuel' do: [:aStream | 
		aStream binary.
		packageNames := (FLMaterializer newDefault materializeFrom: aStream) root. 
	].

	packageNames do: [:aPackageName |
		aDirectory readOnlyFileNamed: (aPackageName,'.fuel') do: [:packageStream | 
			packageStream binary.
			packages add: (FLPackageLoader new loadFrom: packageStream).
			].
		].
	
	packages do: [:each |each initializeClasses. ].! !

!FLPackageLoader methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/20/2012 15:09'!
loadSortedPackagesFromOneBundle: aStream 
	"This method should only be used if you have stored with the method #storeInOneBundleSortedPackageNames: packageNames on: aStream. This method does the initialization of classes in the order the packages were originally provided.  "
	| packageNames package packages |
	aStream binary.
	packageNames := (FLMaterializer newDefault materializeFrom: aStream) root. 
	packages := OrderedCollection new.
	packageNames do: [:each | packages add: (FLPackageLoader new loadFrom: aStream)].
	packages do: [:each |each initializeClasses ].! !

!FLPackageLoader methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/22/2012 15:01'!
materializeFrom: aStream
	| packageHeader package |
	packageHeader := (FLMaterializer newDefault materializeFrom: aStream) root.
	packageHeader executePreMaterializationActions.
	package := (FLMaterializer newDefault materializeFrom: aStream) root.	
	"We put back the header we nilled during export."
	package packageHeader: packageHeader.
	^ package! !

Object subclass: #FLPackageStore
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoader'!

!FLPackageStore methodsFor: 'private' stamp: 'mariano 5/18/2012 19:10'!
exportPackage: package on: aStream
	"First, we serialize the package header and then the pacakge itself"
	FLSerializer newFull serialize: package packageHeader on: aStream. 
	
	
	"Now we nil the packageHeader from the FLPackage to avoid serializing it again. Then during materialization we put it back just in case."
	package packageHeader: nil.
	FLSerializer newFull
		analyzer:
				(FLPackageAnalyzer newDefault
						considerInternalAllBehaviors: package behaviors;
						considerInternalAllMethods: package originalExtensionMethods;
						yourself);
		serialize: package on: aStream! !

!FLPackageStore methodsFor: 'storing' stamp: 'MarianoMartinezPeck 5/20/2012 15:15'!
storeInDifferentStreamsSortedPackageNames: packageNames onDirectory: aDirecotory
	"This method expects that the list of packageNames is sorted in the way they should be initialized. This method is useful if the list of packageNames comes for example, from a Metacello configuration. What we do is to serialize each package in a different stream (a file named as the package name in the provided directory) and we also store the names and order of the packages. To import, you have to use #loadSortedPackagesFromDifferentStreamsInDirectory: that does not do the normal class side #initialize but instead it initializes the packages in the stored order."
	| package |
	
	aDirecotory forceNewFileNamed: ('listOfPackagesInOrder.fuel') do: [:aStream |
		aStream binary.
		FLSerializer serialize: packageNames on: aStream.
	].

	packageNames do: [:aPackage |
		 aDirecotory forceNewFileNamed: (aPackage, '.fuel') do: [:aStream |
			aStream binary.
			package := FLPackage named: aPackage.
			package mustInitialize: false.
			self exportPackage: package on: aStream.
		]
	]! !

!FLPackageStore methodsFor: 'storing' stamp: 'MarianoMartinezPeck 5/20/2012 13:01'!
storeInOneBundleSortedPackageNames: packageNames on: aStream
	"This method expects that the list of packageNames is sorted in the way they should be initialized. This method is useful if the list of packageNames comes for example, from a Metacello configuration. What we do is to serialize all packages together in the same stream and we also store the names and order of the packages. To import, you have to use #loadSortedPackagesFromOneBundle: that does not do the normal class side #initialize but instead it initializes the packages in the stored order."
	| package |
	
	aStream binary.
	FLSerializer serialize: packageNames on: aStream.
	
	packageNames do: [:aPackage |
			package := FLPackage named: aPackage.
			package mustInitialize: false.
			self exportPackage: package on: aStream.
		]
	! !

!FLPackageStore methodsFor: 'storing' stamp: 'MarianoMartinezPeck 5/16/2012 19:43'!
storePackage: aFLPackage on: aStream 
	self exportPackage: aFLPackage on: aStream! !

!FLPackageStore methodsFor: 'storing' stamp: 'MarianoMartinezPeck 5/16/2012 19:43'!
storePackageNamed: name on: aStream 
	| package |
	package := FLPackage named: name.
	self exportPackage: package on: aStream! !

!FLPackageStore methodsFor: 'storing' stamp: 'MarianoMartinezPeck 5/16/2012 19:43'!
storePackagesNamed: names on: aStream 
	| package |
	package := FLPackage withPackages: names.
	self exportPackage: package on: aStream! !

Object subclass: #ManifestFuelPackageLoader
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoader'!

!ManifestFuelPackageLoader class methodsFor: 'meta data' stamp: 'MarianoMartinezPeck 4/21/2012 00:13'!
rejectClasses
^ #()! !

!ManifestFuelPackageLoader class methodsFor: 'meta data' stamp: 'MarianoMartinezPeck 4/21/2012 00:13'!
rejectRules
^ #()! !

!ManifestFuelPackageLoader class methodsFor: 'meta data' stamp: 'MarianoMartinezPeck 4/21/2012 17:25'!
ruleClassNotReferencedRuleV1FalsePositive
^ #(#('(RGClassDefinition named: #FLMetacelloStore)' #'2012-04-21T17:25:46.02+02:00') )! !

!ManifestFuelPackageLoader class methodsFor: 'meta data' stamp: 'MarianoMartinezPeck 4/21/2012 17:26'!
ruleCodeCruftLeftInMethodsRuleV1FalsePositive
^ #(#('(RGMethodDefinition className: ''FLPackageLoaderGeneralMapper'' selector: #visitMetaclass: isMetaSide: false)' #'2012-04-21T17:26:41.256000001+02:00') )! !

!ManifestFuelPackageLoader class methodsFor: 'meta data' stamp: 'MarianoMartinezPeck 4/21/2012 17:36'!
ruleLawOfDemeterRuleV1FalsePositive
^ #(#('(RGMethodDefinition className: ''FLMetacelloStore'' selector: #loadingScriptString isMetaSide: false)' #'2012-04-21T17:36:41.183000001+02:00') #('(RGMethodDefinition className: ''FLPackageLoaderGeneralMapper'' selector: #visitMetaclass: isMetaSide: false)' #'2012-04-21T17:36:41.547000001+02:00') )! !

!ManifestFuelPackageLoader class methodsFor: 'meta data' stamp: 'MarianoMartinezPeck 4/21/2012 18:13'!
ruleOnlyReadOrWrittenTemporaryRuleV1TruePositive
^ #(#('(RGMethodDefinition className: ''ClassOrganizer'' selector: #classifySilently:under:suppressIfDefault: isMetaSide: false)' #'2012-04-21T18:13:46.796000001+02:00') )! !

!Object methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 9/22/2011 02:12'!
rebindOn: aCompiledMethod at: index
	"Nothing to do."! !

!ClassDescription methodsFor: '*FuelPackageLoader' stamp: 'MarianoMartinezPeck 5/24/2012 15:09'!
foreignCategories
	
	"We cannot remove Fuel extension methods because they are needed by Fuel itself!!"
	^(self organization categories select: [ :aCategory | aCategory beginsWith: '*' ]) reject: [:each | each beginsWith: '*Fuel']! !

!ClassDescription methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 8/22/2011 01:50'!
removeCategorySilently: aCategory

	(organization listAtCategoryNamed: aCategory) do: [ :aSelector | self removeSelectorSilently: aSelector ].
	organization removeCategorySilently: aCategory.
! !

!ClassDescription methodsFor: '*FuelPackageLoader' stamp: 'MartinDias 8/22/2011 03:05'!
removeForeignProtocol

	self foreignCategories do: [ :aCategory |
		self removeCategorySilently: aCategory ]! !
